@@ -315,7 +315,7 @@ class R3sponse(object):
 			for key, value in self.items():
 				if serializable:
 					if isinstance(value, object) and not isinstance(value, dict) and not isinstance(value, list):
-						value = f"{value}"
+						value = str(value)
 					elif isinstance(value, str) or isinstance(value, bool) or value == None:
 						if value in [True, "True", "True".lower()]: 
 							if json:
@@ -378,7 +378,7 @@ class R3sponse(object):
 			delattr(self, key)
 		# string format.
 		def __str__(self):
-			return self.json(indent=4) # necessary for str(self)
+			return self.json(indent=4) 
 		def json(self, indent=4):
 			return json.dumps(self.dict(serializable=True, json=True), indent=indent).replace(': "None"', ': null').replace(': "False"', ': false').replace(': "True"', ': true')
 		#def __dict__(self):
